@@ -6,7 +6,7 @@ use open ':utf8';
 use base 'Exporter';
 use base 'POD2::Base';
 
-our $VERSION = '5.22.0.2';
+our $VERSION = '5.22.0.3';
 
 our @EXPORT = qw(print_pod print_pods);
 
@@ -26,7 +26,7 @@ sub pod_info {{
     perlfaq1          => '5.22.0',
     perlfaq2          => '5.22.0',
     perlfreebsd       => '5.22.0',
-    perlgit           => '5.22.0',
+    #perlgit           => '5.22.0',
     #perlglossary      => '5.22.0',
     perlhacktut       => '5.22.0',
     #perlhist          => '5.22.0',
@@ -41,7 +41,7 @@ sub pod_info {{
     perlootut         => '5.22.0',
     perlopenbsd       => '5.22.0',
     perlpragma        => '5.22.0',
-    perlre            => '5.22.0',
+    #perlre            => '5.22.0',
     perlsource        => '5.22.0',
     perlstyle         => '5.22.0',
     perltodo          => '5.22.0',
